==> ips.speechrecorder-4.6.0-sources.jar: ipsk/apps/speechrecorder/script/ui/ExportScriptUIDialog.java <==
//    Speechrecorder
//    (c) Copyright 2012
// 	  Institute of Phonetics and Speech Processing,
//    Ludwig-Maximilians-University, Munich, Germany
//
//
//    This file is part of Speechrecorder
//
//
//    Speechrecorder is free software: you can redistribute it and/or modify
//    it under the terms of the GNU Lesser General Public License as published by
//    the Free Software Foundation, version 3 of the License.
//
//    Speechrecorder is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU Lesser General Public License for more details.
//
//    You should have received a copy of the GNU Lesser General Public License
//    along with Speechrecorder.  If not, see <http://www.gnu.org/licenses/>.

package ipsk.apps.speechrecorder.script.ui;

import ipsk.db.speech.Script;
import ipsk.swing.JDialogPanel;
import ipsk.swing.text.TableTextfileExporter;
import ipsk.text.TableTextFormats;
import ipsk.util.SystemHelper;

public class ExportScriptUIDialog extends JDialogPanel{

    private TableTextfileExporter<Script.ScriptTableSchemaProvider,Script> tableTextfileExporter;
	

	public ExportScriptUIDialog() {
	    super(JDialogPanel.Options.NONE);
	    
	    setFrameTitle("Export recording script to text list/table");
	    setApplyingEnabled(false);
        tableTextfileExporter=new TableTextfileExporter<Script.ScriptTableSchemaProvider,Script>(Script.scriptTableSchemaProvider);
        TableTextFormats.Profile defaultProfile;
        if(SystemHelper.getInstance().isWindows()){
            defaultProfile=TableTextFormats.Profile.TAB_SEP_WIN;
        }else{
            defaultProfile=TableTextFormats.Profile.TAB_SEP_UNIX;
        }
        tableTextfileExporter.setSelectedProfile(defaultProfile);
        add(tableTextfileExporter);
       
	}

   public void setScript(Script script){
       tableTextfileExporter.setData(script);
   }

}

==> ips.speechrecorder-6.2.8-sources.jar: ipsk/apps/speechrecorder/script/ui/ExportScriptUIDialog.java <==
//    Speechrecorder
//    (c) Copyright 2012
// 	  Institute of Phonetics and Speech Processing,
//    Ludwig-Maximilians-University, Munich, Germany
//
//
//    This file is part of Speechrecorder
//
//
//    Speechrecorder is free software: you can redistribute it and/or modify
//    it under the terms of the GNU Lesser General Public License as published by
//    the Free Software Foundation, version 3 of the License.
//
//    Speechrecorder is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU Lesser General Public License for more details.
//
//    You should have received a copy of the GNU Lesser General Public License
//    along with Speechrecorder.  If not, see <http://www.gnu.org/licenses/>.

package ipsk.apps.speechrecorder.script.ui;

import ipsk.db.speech.script.Script;
import ipsk.swing.JDialogPanel;
import ipsk.swing.text.TableTextfileExporter;
import ipsk.text.TableTextFormats;
import ipsk.util.SystemHelper;

public class ExportScriptUIDialog extends JDialogPanel{

    private TableTextfileExporter<Script.ScriptTableSchemaProvider,Script> tableTextfileExporter;
	

	public ExportScriptUIDialog() {
	    super(JDialogPanel.Options.NONE);
	    
	    setFrameTitle("Export recording script to text list/table");
	    setApplyingEnabled(false);
        tableTextfileExporter=new TableTextfileExporter<Script.ScriptTableSchemaProvider,Script>(Script.scriptTableSchemaProvider);
        TableTextFormats.Profile defaultProfile;
        if(SystemHelper.getInstance().isWindows()){
            defaultProfile=TableTextFormats.Profile.TAB_SEP_WIN;
        }else{
            defaultProfile=TableTextFormats.Profile.TAB_SEP_UNIX;
        }
        tableTextfileExporter.setSelectedProfile(defaultProfile);
        add(tableTextfileExporter);
       
	}

   public void setScript(Script script){
       tableTextfileExporter.setData(script);
   }

}
